# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)

# MRO is part of the Perl core since 5.9.5
%global mro_in_core %(perl -e 'print $] > 5.009005 ? 1 : 0;')

Name:		perl-Class-C3
Version:	0.26
Release:	1.%{__distinit}%{__distvers}
Summary:	Pragma to use the C3 method resolution order algorithm
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Class-C3/
Source0:	http://search.cpan.org/CPAN/authors/id/H/HA/HAARG/Class-C3-%{version}.tar.gz
Patch0:		Class-C3-0.25-old-Test::More.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Build
BuildRequires:	perl(ExtUtils::CBuilder) >= 0.27
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module
BuildRequires:	perl(Algorithm::C3) >= 0.07
BuildRequires:	perl(Scalar::Util) >= 1.09
# Test suite
BuildRequires:	perl(base)
BuildRequires:	perl(lib)
BuildRequires:	perl(NEXT)
BuildRequires:	perl(Devel::Hide)
BuildRequires:	perl(File::Glob)
BuildRequires:	perl(Sub::Name)
BuildRequires:	perl(Test::Exception) >= 0.15
BuildRequires:	perl(Test::More) >= 0.47
BuildRequires:	perl(Test::Pod)
BuildRequires:	perl(Test::Pod::Coverage)
# MRO::Compat itself requires Class::C3
# The test that uses the module is skipped unless MRO is part of the Perl core
%if 0%{!?perl_bootstrap:1} && %{mro_in_core}
BuildRequires:	perl(MRO::Compat)
%endif
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
Requires:	perl(Algorithm::C3) >= 0.07
Requires:	perl(Scalar::Util) >= 1.09

# Requirements for older distributions with Perl < 5.9.5
%if ! %{mro_in_core}
BuildRequires:	perl(Class::C3::XS) >= 0.13
Requires:	perl(Class::C3::XS) >= 0.13
%endif

# Let people "use c3;"
Provides:	perl(c3) = %{version}

# Filter out bogus dependencies and provides (rpm 4.9 onwards)
%global __requires_exclude ^perl\\((c3|base)\\)
%global __provides_exclude ^perl\\(t::lib::

%description
This is a pragma to change Perl 5's standard method resolution order from
depth-first left-to-right (a.k.a - pre-order) to the more sophisticated C3
method resolution order.

%prep
%setup -q -n Class-C3-%{version}

# We need to patch the test suite if we have an old version of Test::More
%if %{old_test_more}
%patch0
%endif

# Filter out bogus dependencies and provides (prior to rpm 4.9)
%global reqfilt /bin/sh -c "%{__perl_requires} | grep -Evx 'perl[(](c3|base)[)]'"
%define __perl_requires %{reqfilt}
%global provfilt /bin/sh -c "%{__perl_provides} | grep -v '^perl(t::lib::'"
%define __perl_provides %{provfilt}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
cp -p opt/c3.pm %{buildroot}%{perl_vendorlib}/
%{_fixperms} %{buildroot}

%check
make test

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc ChangeLog README util/ t/
%{perl_vendorlib}/c3.pm
%{perl_vendorlib}/Class/
%{_mandir}/man3/Class::C3.3pm*
%{_mandir}/man3/Class::C3::next.3pm*

%changelog
* Wed Mar  5 2014 Paul Howarth <paul@city-fan.org> - 0.26-1
- Update to 0.26:
  - Fix bug in Makefile.PL when ExtUtils::CBuilder not available
- This release by HAARG -> update source URL
- Drop now-redundant Module::Install build dependencies

* Mon Jul 22 2013 Paul Howarth <paul@city-fan.org> - 0.25-2
- Perl 5.18 rebuild

* Thu Jul  4 2013 Paul Howarth <paul@city-fan.org> - 0.25-1
- Update to 0.25:
  - Drop compatibility from 5.6.2 to 5.6.0
  - Pod typo fixes (CPAN RT#77453, CPAN RT#85357)
  - Only ask for Devel::Hide on perls where it will be actually used
    (CPAN RT#81106)
  - Fix SYNOPSIS to actually be executable (CPAN RT#78327)
- This release by MSTROUT -> update source URL
- BR: perl(ExtUtils::CBuilder) and perl(File::Glob)
- Bump perl(Class::C3::XS) version requirement to 0.13
- Update old Test::More patch

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 0.24-3
- Perl 5.16 post-bootstrap rebuild

* Mon Jul  9 2012 Paul Howarth <paul@city-fan.org> - 0.24-2
- BR: perl(Cwd) and perl(File::Path) for bundled Module::Install
- BR: perl(base), perl(lib), perl(NEXT) and perl(Devel::Hide) for test suite
- Add patch to support building with Test::More < 0.88

* Sat May 12 2012 Paul Howarth <paul@city-fan.org> - 0.24-1
- Update to 0.24:
  - Require Class::C3::XS on 5.8 perls if a working compiler is found
- Bump Algorithm::C3 version requirement to 0.07
- Always BR:/R: Algorithm::C3 and Scalar::Util
- Don't need to remove empty directories from buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Thu Jan 19 2012 Paul Howarth <paul@city-fan.org> - 0.23-4
- Resync with Rawhide package

* Wed Jun 22 2011 Paul Howarth <paul@city-fan.org> - 0.23-3
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Update bogus dependency and provides filters for rpm 4.9.x
- Drop provides hack for #205801, no longer needed
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 0.23-2
- Rebuild for perl 5.12.1 in Rawhide

* Sat Jun 19 2010 Paul Howarth <paul@city-fan.org> - 0.23-1
- Update to 0.23 (fix various documentation problems)

* Mon May 17 2010 Paul Howarth <paul@city-fan.org> - 0.22-3
- MRO in perl core from 5.9.5 - don't require Algorithm::C3 or Class::C3::XS
- Include c3.pm in %%{perl_vendorlib} rather than %%doc

* Tue May 11 2010 Paul Howarth <paul@city-fan.org> - 0.22-2
- Fix dist tag for RHEL-6 Beta

* Fri Jan 29 2010 Paul Howarth <paul@city-fan.org> - 0.22-1
- Update to 0.22 (document that MRO::Compat is preferred API)
- Use %%{_fixperms} macro rather than our own %%{__chmod} incantation
- Dist tag for Rawhide no longer needs special-casing

* Tue Aug 11 2009 Paul Howarth <paul@city-fan.org> - 0.21-3
- Import from Fedora

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.21-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Apr 02 2009 Chris Weyl <cweyl@alumni.drew.edu> - 0.21-1
- Update to 0.21

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.20-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Jan 25 2009 Chris Weyl <cweyl@alumni.drew.edu> - 0.20-1
- Update to 0.20

* Tue Mar  4 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.19-2
- Rebuild for new perl

* Wed Oct 10 2007 Chris Weyl <cweyl@alumni.drew.edu> - 0.19-1
- Update to 0.19

* Fri Jun 01 2007 Chris Weyl <cweyl@alumni.drew.edu> - 0.18-1
- Update to 0.18

* Wed May 09 2007 Chris Weyl <cweyl@alumni.drew.edu> - 0.17-1
- Update to 0.17
- BR Class::C3::XS

* Mon Sep 25 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.14-1
- Update to 0.14

* Tue Sep 19 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.13-4
- Fix autoprovides (#205801)

* Thu Sep 07 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.13-3
- Bump

* Thu Sep 07 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.13-2
- Additional br's, minor spec tweaks

* Tue Sep 05 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.13-1
- Specfile autogenerated by cpanspec 1.69.1
